YkAudioUtil class
- Mixed-in types
Properties
- currentPlayingAudioID ↔ String?
-
getter/setter pair
- duration ↔ double
-
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- hasListeners → bool
-
Whether any listeners are currently registered.
no setterinherited
- isPause ↔ bool
-
getter/setter pair
- isPlaying ↔ bool
-
getter/setter pair
- position ↔ double
-
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
addListener(
VoidCallback listener) → void -
Register a closure to be called when the object changes.
inherited
-
dispose(
) → void -
Discards any resources used by the object.
override
-
end(
) → Future -
init(
{required YkAudioUtilDelegate delegate}) → Future -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
notifyListeners(
) → void -
Call all the registered listeners.
inherited
-
pause(
) → Future -
play(
{required String audioID, void progressCallBack(double duration, double position)?, void finishCallBack()?}) → Future -
register(
{required String audioID, required String audioUrl}) → Future -
removeListener(
VoidCallback listener) → void -
Remove a previously registered closure from the list of closures that are
notified when the object changes.
inherited
-
resume(
) → Future -
seekTo(
{required double progress}) → Future -
toString(
) → String -
A string representation of this object.
inherited
-
unInit(
) → Future
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Properties
- instance → YkAudioUtil
-
no setter