YKCameraPhoto class

相机拍照工具类

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

instance YKCameraPhoto
final

Static Methods

pick<T>({Map<String, dynamic>? params}) Future<T?>
拍照
reset() → void
重置状态
setup({required YKCameraPhotoDelegate delegate}) Future<void>
初始化设置