YKCameraPhotoDelegate mixin

相机拍照代理接口

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

checkAuth() Future<bool>
检查权限
init() Future<void>
初始化设置
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
pickPhoto(Map<String, dynamic>? params) Future
拍照
toString() String
A string representation of this object.
inherited
unInit() Future<void>
释放资源

Operators

operator ==(Object other) bool
The equality operator.
inherited