ModuleResult<T> class

模块执行结果

Constructors

ModuleResult({required bool success, T? data, Object? error})
const
ModuleResult.failure(Object error)
factory
ModuleResult.success(T? data)
factory

Properties

data → T?
final
error Object?
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
success bool
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited