YKDiskManagerModule mixin
磁盘管理模块接口
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
endModule(
String targetModule, Map< String, dynamic> params) → Future<bool> - 结束模块
-
executeModule(
Map< String, dynamic> params) → Future - 执行模块
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited