YKImagePicker class

图片选择器工具类

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
pick<T>({dynamic params, int maxCount = 9}) Future<T?>
选择图片
reset() Future
重置状态
setup({required YKImagePickerDelegate delegate}) Future<void>
初始化设置
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

instance YKImagePicker
final