YkRtcManager class

Available extensions

Properties

hashCode int
The hash code for this object.
no setterinherited
messageStream Stream<YkRtcManagerMessageModel>
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

changeCamera({required bool frontCamera}) Future<int?>

Available on YkRtcManager, provided by the YkRtcManagerPublic extension

切换摄像头
config({required YkRtcManagerDelegate delegate}) Future<void>
createWidget(dynamic onViewCreated(int viewId)) Widget
dispose() Future<void>

Available on YkRtcManager, provided by the YkRtcManagerPublic extension

enterRoom({required String roomId, bool isLive = false, dynamic params}) Future<void>

Available on YkRtcManager, provided by the YkRtcManagerPublic extension

exitRoom({required String roomId, dynamic params}) Future<void>

Available on YkRtcManager, provided by the YkRtcManagerPublic extension

init() Future<void>

Available on YkRtcManager, provided by the YkRtcManagerPublic extension

login({dynamic params}) Future

Available on YkRtcManager, provided by the YkRtcManagerPublic extension

logout({dynamic params}) Future

Available on YkRtcManager, provided by the YkRtcManagerPublic extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
openMic({required bool isOpen}) Future<void>

Available on YkRtcManager, provided by the YkRtcManagerPublic extension

openSpeaker({required bool isOpen}) Future<void>

Available on YkRtcManager, provided by the YkRtcManagerPublic extension

startLocalPreview({required int viewId, bool frontCamera = false}) Future<void>

Available on YkRtcManager, provided by the YkRtcManagerPublic extension

startRemoteView({required String userId, required int viewId}) Future<void>

Available on YkRtcManager, provided by the YkRtcManagerPublic extension

startStreaming() Future<void>

Available on YkRtcManager, provided by the YkRtcManagerPublic extension

stopLocalPreview() Future<void>

Available on YkRtcManager, provided by the YkRtcManagerPublic extension

停止本地视频推流
stopRemoteView({required String userId}) Future<void>

Available on YkRtcManager, provided by the YkRtcManagerPublic extension

停止远端视频拉流
stopStreaming() Future<void>

Available on YkRtcManager, provided by the YkRtcManagerPublic extension

switchRole({required bool isAnchor}) Future<void>

Available on YkRtcManager, provided by the YkRtcManagerPublic extension

toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

instance YkRtcManager
no setter