YKSocketDelegate class

Socket 代理回调

Constructors

YKSocketDelegate({void onConnectFail()?, void onConnectSuccess()?, void onError(String message)?, void onLog(String message)?, void onClose()?, void onReconnecting()?})
const

Properties

hashCode int
The hash code for this object.
no setterinherited
onClose → void Function()?
final
onConnectFail → void Function()?
final
onConnectSuccess → void Function()?
final
onError → void Function(String message)?
final
onLog → void Function(String message)?
final
onReconnecting → void Function()?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited