YkSocket class

WebSocket 实现

Available extensions

Constructors

YkSocket({Duration reconnectDelay = const Duration(seconds: 2), int maxReconnectAttempts = 3})

Properties

hashCode int
The hash code for this object.
no setterinherited
maxReconnectAttempts int
final
messageStream Stream
获取消息流
no setter
reconnectDelay Duration
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
state SocketState
获取当前状态
no setter
stateStream Stream<SocketState>
获取状态流
no setter

Methods

close() Future<void>

Available on YkSocket, provided by the YkSocketPublic extension

关闭连接
connect({required String url, required YKSocketDelegate delegate}) Future<void>

Available on YkSocket, provided by the YkSocketPublic extension

连接
dispose() Future

Available on YkSocket, provided by the YkSocketPublic extension

释放资源
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
send(dynamic message) Future<void>

Available on YkSocket, provided by the YkSocketPublic extension

发送消息
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited