YkStorage class

存储工具类

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

instance YkStorage
final

Static Methods

clear({bool isOnce = true}) Future<void>
清除数据
get<T>({required String key}) Future<T?>
获取存储数据
init({required YkStorageDelegate delegate}) Future<void>
初始化存储
save({required String key, required dynamic data, bool isOnce = true}) Future<void>
保存数据