YKDiskManager class
磁盘管理器
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Properties
- instance → YKDiskManager
-
final
-
registeredModules
→ List<
String> -
获取已注册的模块列表
no setter
Static Methods
-
clear(
) → void - 清除所有模块
-
hasModule(
String module) → bool - 检查模块是否已注册
-
openModule<
T> ({required String module, required Map< String, dynamic> params, void onError(Object error)?}) → Future<ModuleResult< T> > - 打开模块
-
registerModule(
String module, YKDiskManagerModule handler) → void - 注册模块
-
unregisterModule(
String module) → void - 移除模块