YkImManager class
Properties
-
connectionState
→ Stream<
ImConnectionState> -
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- isConnected → bool
-
no setter
- messageStream → Stream
-
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
config(
{required YkImManagerDelegate delegate}) → Future< void> -
dispose(
) → Future< void> -
init(
{dynamic params, KickedOfflineCallback? onKickedOffline}) → Future< void> -
joinGroup(
{required String groupId, dynamic params}) → Future< void> -
login(
{dynamic params}) → Future< void> -
logout(
{dynamic params}) → Future< void> -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
quitGroup(
{String? groupId, dynamic params}) → Future< void> -
sendMessage(
{String? groupId, String? content, String? imagePath, String? customData, dynamic params}) → Future -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Properties
- instance → YkImManager
-
final