YKTaskUtil class
任务工具类
Constructors
Properties
- currentIndex → int
-
获取当前执行的任务索引
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- lastError → String?
-
获取最后的错误信息
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- taskCount → int
-
获取任务总数
no setter
Methods
-
addTask(
TaskAction action, {String? taskName}) → void - 添加任务
-
clear(
) → void - 清除所有任务
-
executeFirstTask(
) → Future< void> - 执行第一个任务
-
insertTask(
int index, TaskAction action, {String? taskName}) → void - 插入任务到指定位置
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
removeTask(
int index) → void - 移除指定位置的任务
-
rollBackToLastTask(
) → void - 回滚到上一个任务
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited